@@ -27,7 +27,6 @@
 #include <signal.h>
 #include <gio/gio.h>
 
-#include "cd-cleanup.h"
 #include "cd-state.h"
 
 #define CD_STATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CD_TYPE_STATE, CdStatePrivate))
@@ -470,7 +469,7 @@ cd_state_show_profile (CdState *state)
 	gdouble total_time = 0.0f;
 	guint i;
 	guint uncumalitive = 0;
-	_cleanup_string_free_ GString *result = NULL;
+	g_autoptr(GString) result = NULL;
 
 	/* get the total time so we can work out the divisor */
 	for (i = 0; i < state->priv->steps; i++)
