@@ -26,7 +26,6 @@
 
 #include <glib.h>
 
-#include "cd-cleanup.h"
 #include "cd-test-shared.h"
 
 /**
@@ -37,7 +36,7 @@ cd_test_get_filename (const gchar *filename)
 {
 	gchar *tmp;
 	char full_tmp[PATH_MAX];
-	_cleanup_free_ gchar *path = NULL;
+	g_autofree gchar *path = NULL;
 
 	/* running in the installed system */
 	if (g_getenv ("INSTALLED_TESTS") != NULL) {
@@ -94,3 +93,29 @@ cd_test_loop_quit (void)
 		_test_loop = NULL;
 	}
 }
+
+/**
+ * cd_test_compare_lines:
+ **/
+gboolean
+cd_test_compare_lines (const gchar *txt1, const gchar *txt2, GError **error)
+{
+	g_autofree gchar *output = NULL;
+
+	/* exactly the same */
+	if (g_strcmp0 (txt1, txt2) == 0)
+		return TRUE;
+
+	/* save temp files and diff them */
+	if (!g_file_set_contents ("/tmp/a", txt1, -1, error))
+		return FALSE;
+	if (!g_file_set_contents ("/tmp/b", txt2, -1, error))
+		return FALSE;
+	if (!g_spawn_command_line_sync ("diff -urNp /tmp/b /tmp/a",
+					&output, NULL, NULL, error))
+		return FALSE;
+
+	/* just output the diff */
+	g_set_error_literal (error, 1, 0, output);
+	return FALSE;
+}
