@@ -25,8 +25,6 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "cd-cleanup.h"
-
 #include "ch-inhx32.h"
 
 #define	CH_RECORD_TYPE_DATA		0
@@ -82,7 +80,7 @@ ch_inhx32_to_bin_full (const gchar *in_buffer,
 	guint j;
 	guint len_tmp;
 	guint type;
-	_cleanup_string_free_ GString *string = NULL;
+	g_autoptr(GString) string = NULL;
 
 	g_return_val_if_fail (in_buffer != NULL, FALSE);
 	g_return_val_if_fail (runcode_addr > 0, FALSE);
