@@ -29,13 +29,11 @@
 
 #include "cd-common.h"
 
-#ifdef USE_POLKIT
-#ifndef PolkitAuthorizationResult_autoptr
+#if defined(USE_POLKIT) && !defined(POLKIT_HAS_AUTOPTR_MACROS)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitAuthorizationResult, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitSubject, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitAuthority, g_object_unref)
 #endif
-#endif
 
 /**
  * cd_client_error_quark:
